@@ -1,6 +1,6 @@
 {-# LANGUAGE CPP               #-}
 {-# LANGUAGE OverloadedStrings #-}
-module Main (main) where
+module Main (main, ex) where
 
 import Prelude                   ()
 import Prelude.Compat
@@ -9,7 +9,8 @@ import Control.Applicative       (Const)
 import Data.List.NonEmpty        (NonEmpty)
 import Data.Proxy                (Proxy)
 import Data.Tagged               (Tagged)
-import Data.Time                 (Day, LocalTime)
+import Data.Text                 (Text)
+import Data.Time                 (Day, LocalTime, NominalDiffTime)
 import Data.Version              (Version)
 import Numeric.Natural           (Natural)
 
@@ -37,6 +38,7 @@ main = defaultMain $ testGroup "Tests"
     , testProperty "Proxy"     $ roundtrip (undefined :: Proxy Int)
     , testProperty "Tagged"    $ roundtrip (undefined :: Tagged Int Int)
     , testProperty "NonEmpty"  $ roundtrip (undefined :: NonEmpty Int)
+    , testProperty "NominalDiffTime" $ roundtrip (undefined :: NominalDiffTime)
     ]
   ]
 
@@ -82,3 +84,10 @@ roundtripBroken10 _ x = property $ case eitherDecode . encode $ x of
 #else
 roundtripBroken10 = roundtrip
 #endif
+
+-------------------------------------------------------------------------------
+-- tests that symbols are exported
+-------------------------------------------------------------------------------
+
+ex :: (Text, Value)
+ex = "foo" .= True
